@@ -1,5 +1,5 @@
 /*!
- * froala_editor v1.2.1 (http://editor.froala.com)
+ * froala_editor v1.2.4 (http://editor.froala.com)
  * Copyright 2014-2014 Froala
  */
 
@@ -15,8 +15,8 @@ $.Editable.LANGS['fa'] = {
     "Strikethrough": "\u062e\u0637 \u062e\u0648\u0631\u062f\u0647",
     "Font Size": "\u0627\u0646\u062f\u0627\u0632\u0647 \u0641\u0648\u0646\u062a",
     "Color": "\u0631\u0646\u06af",
-    "Background Color": "\u0631\u0646\u06af \u0632\u0645\u06cc\u0646\u0647 \u0645\u062a\u0646",
-    "Text Color": "\u0631\u0646\u06af \u0645\u062a\u0646",
+    "Background": "\u0632\u0645\u06cc\u0646\u0647 \u0645\u062a\u0646",
+    "Text": "\u0645\u062a\u0646",
     "Format Block": "\u0642\u0627\u0644\u0628",
     "Normal": "\u0637\u0628\u06cc\u0639\u06cc - Normal",
     "Paragraph": "\u067e\u0627\u0631\u0627\u06af\u0631\u0627\u0641 - Paragraph",
@@ -51,7 +51,6 @@ $.Editable.LANGS['fa'] = {
     "Replace Image": "\u0628\u0647 \u062c\u0627\u06cc \u062a\u0635\u0648\u06cc\u0631",
     "Remove Image": "\u062d\u0630\u0641 \u062a\u0635\u0648\u06cc\u0631",
     "Title": "\u0639\u0646\u0648\u0627\u0646",
-    "Insert image": "\u0627\u0636\u0627\u0641\u0647 \u06a9\u0631\u062f\u0646 \u062a\u0635\u0648\u06cc\u0631",
     "Drop image": "\u0642\u0637\u0631\u0647 \u062a\u0635\u0648\u06cc\u0631",
     "or click": "\u06cc\u0627 \u06a9\u0644\u06cc\u06a9 \u06a9\u0646\u06cc\u062f",
     "or": "\u0648 \u06cc\u0627",
@@ -84,7 +83,11 @@ $.Editable.LANGS['fa'] = {
     "Delete row": "\u062d\u0630\u0641 \u0633\u0637\u0631",
     "Insert column before": "\u062f\u0631\u062c \u0633\u062a\u0648\u0646 \u0642\u0628\u0644",
     "Insert column after": "\u062f\u0631\u062c \u0633\u062a\u0648\u0646 \u0628\u0639\u062f",
-    "Delete column": "\u062d\u0630\u0641 \u0633\u062a\u0648\u0646"
+    "Delete column": "\u062d\u0630\u0641 \u0633\u062a\u0648\u0646",
+    "Uploading image": "\u0622\u067e\u0644\u0648\u062f \u062a\u0635\u0648\u06cc\u0631",
+    "Upload File": "\u0622\u067e\u0644\u0648\u062f \u0641\u0627\u06cc\u0644",
+    "Drop File": "\u0627\u0641\u062a \u0641\u0627\u06cc\u0644",
+    "Clear formatting": "\u062d\u0630\u0641 \u0642\u0627\u0644\u0628 \u0628\u0646\u062f\u06cc"
   },
   direction : "rtl"
-};
\ No newline at end of file
+};
